@@ -12,3 +12,5 @@
 PCLUSTER_STACK_PREFIX = "parallelcluster-"
 PCLUSTER_ISSUES_LINK = "https://github.com/aws/aws-parallelcluster/issues"
 CIDR_ALL_IPS = "0.0.0.0/0"
+DEFAULT_ARCHITECTURE = "x86_64"
+SUPPORTED_ARCHITECTURES = ["x86_64", "arm64"]
